@@ -1,5 +1,5 @@
 package App::SmokeBrew::Plugin::BINGOS;
-$App::SmokeBrew::Plugin::BINGOS::VERSION = '0.12';
+$App::SmokeBrew::Plugin::BINGOS::VERSION = '0.14';
 #ABSTRACT: a smokebrew plugin to configure things like BINGOS does
 
 use strict;
@@ -46,7 +46,7 @@ BEGIN {
 
     $ENV{'PERL5LIB'} = join $Config{'path_sep'}, grep { defined }
                         $PRIV_LIB,              # to find the boxed config
-                        #$LIB_DIR,               # the CPANPLUS libs
+                        $LIB_DIR,               # the CPANPLUS libs
                         $ENV{'PERL5LIB'};       # original PERL5LIB
 
 }
@@ -203,7 +203,7 @@ App::SmokeBrew::Plugin::BINGOS - a smokebrew plugin to configure things like BIN
 
 =head1 VERSION
 
-version 0.12
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -268,7 +268,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Chris Williams.
+This software is copyright (c) 2017 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
